@@ -24,7 +24,7 @@
 #include "downloadwidget.h"
 #include "downloadwidget_p.h"
 
-#include <QtCore/QTimer>
+#include <QTimer>
 #include <QScrollBar>
 #include <QKeyEvent>
 #include <QCoreApplication>
@@ -48,7 +48,7 @@ DownloadWidget::DownloadWidget(QWidget *parent)
     , d(new DownloadWidgetPrivate(this))
 {
     const QString name = QCoreApplication::applicationName();
-    init(name + ".knsrc");
+    init(name + QStringLiteral(".knsrc"));
 }
 
 DownloadWidget::DownloadWidget(const QString &configFile, QWidget *parent)
@@ -133,10 +133,12 @@ void DownloadWidgetPrivate::slotNetworkTimeout() // SLOT
 
 void DownloadWidgetPrivate::sortingChanged()
 {
-    KNSCore::Provider::SortMode sortMode = KNSCore::Provider::Newest;
+    KNSCore::Provider::SortMode sortMode = KNSCore::Provider::Rating;
     KNSCore::Provider::Filter filter = KNSCore::Provider::None;
     if (ui.ratingRadio->isChecked()) {
         sortMode = KNSCore::Provider::Rating;
+    } else if (ui.newestRadio->isChecked()) {
+        sortMode = KNSCore::Provider::Newest;
     } else if (ui.mostDownloadsRadio->isChecked()) {
         sortMode = KNSCore::Provider::Downloads;
     } else if (ui.installedRadio->isChecked()) {
@@ -167,7 +169,7 @@ void DownloadWidgetPrivate::slotSearchTextChanged()
         return;
     }
     searchTerm = ui.m_searchEdit->text().trimmed();
-    engine->setSearchTerm(ui.m_searchEdit->text().trimmed());
+    engine->setSearchTerm(searchTerm);
 }
 
 void DownloadWidgetPrivate::slotCategoryChanged(int idx)
@@ -222,7 +224,7 @@ void DownloadWidgetPrivate::slotError(const QString &message)
 
 void DownloadWidgetPrivate::scrollbarValueChanged(int value)
 {
-    if ((double)value / ui.m_listView->verticalScrollBar()->maximum() > 0.9) {
+    if (static_cast<double>(value) / ui.m_listView->verticalScrollBar()->maximum() > 0.9) {
         engine->requestMoreData();
     }
 }
@@ -240,7 +242,7 @@ void DownloadWidgetPrivate::init(const QString &configFile)
     q->connect(engine, &KNSCore::Engine::signalMessage, this, &DownloadWidgetPrivate::slotShowMessage);
 
     q->connect(engine, &KNSCore::Engine::signalBusy, ui.progressIndicator, &ProgressIndicator::busy);
-    q->connect(engine, &KNSCore::Engine::signalError, ui.progressIndicator, &ProgressIndicator::error);
+    q->connect(engine, &KNSCore::Engine::signalErrorCode, ui.progressIndicator, &ProgressIndicator::error);
     q->connect(engine, &KNSCore::Engine::signalIdle, ui.progressIndicator, &ProgressIndicator::idle);
 
     q->connect(engine, &KNSCore::Engine::signalProvidersLoaded, this, &DownloadWidgetPrivate::slotProvidersLoaded);
@@ -255,6 +257,7 @@ void DownloadWidgetPrivate::init(const QString &configFile)
                model, &KNSCore::ItemsModel::slotEntryPreviewLoaded);
 
     engine->init(configFile);
+    engine->setSortMode(KNSCore::Provider::Rating);
 
     delegate = new ItemsViewDelegate(ui.m_listView, engine, q);
     ui.m_listView->setItemDelegate(delegate);
@@ -361,7 +364,7 @@ void DownloadWidgetPrivate::slotProvidersLoaded()
 
 void DownloadWidgetPrivate::slotEntriesLoaded(const KNSCore::EntryInternal::List &entries)
 {
-    foreach (const KNSCore::EntryInternal &entry, entries) {
+    for (const KNSCore::EntryInternal &entry : entries) {
         if (!categories.contains(entry.category())) {
             qCDebug(KNEWSTUFF) << "Found category: " << entry.category();
             categories.insert(entry.category());
